@@ -5,18 +5,24 @@ import os
 from pathlib import Path
 import shutil
 import subprocess as sp
-import sys
-from typing import Optional, Tuple
+from typing import Mapping, Optional, Tuple
 
+from pyscreener.utils import AutoName
 from pyscreener.exceptions import (
     MissingEnvironmentVariableError,
     MisconfiguredDirectoryError,
+    ReceptorPreparationError,
+)
+from pyscreener.docking.dock.exceptions import (
+    BoxGenerationError,
+    GridGenerationError,
+    SphereGenerationError,
+    SurfaceGenerationError,
 )
-from pyscreener.utils import AutoName
 
 with resources.path("pyscreener.docking.dock", ".") as p_module:
-    PREP_REC = p_module / "scripts" / "prep_rec.py"
-    WRITE_DMS = p_module / "scripts" / "write_dms.py"
+    PREP_REC = p_module / "scripts" / "prep_rec.py2"
+    WRITE_DMS = p_module / "scripts" / "write_dms.py2"
 
 try:
     DOCK6 = Path(os.environ["DOCK6"])
@@ -48,92 +54,20 @@ class SphereMode(AutoName):
     LIGAND = auto()
 
 
-def prepare_receptor(
-    receptor: str,
-    probe_radius: float = 1.4,
-    steric_clash_dist: float = 0.0,
-    min_radius: float = 1.4,
-    max_radius: float = 4.0,
-    sphere_mode: SphereMode = SphereMode.LARGEST,
-    center: Optional[Tuple[float, float, float]] = None,
-    size: Tuple[float, float, float] = (10.0, 10.0, 10.0),
-    docked_ligand_file: Optional[str] = None,
-    buffer: float = 10.0,
-    enclose_spheres: bool = True,
-    path: str = ".",
-) -> Optional[Tuple[str, str]]:
-    """Prepare the DOCK input files corresponding to the given receptor
-
-    Parameters
-    ----------
-    receptor : str
-        the filepath of a file containing a receptor. Must be in a file that
-        is readable by Chimera
-    center : Tuple[float, float, float]
-        the x-, y-, and z-coordinates of the center of the docking box
-    size : Tuple[float, float, float] (Default = (20, 20, 20))
-        the x-, y-, and z-radii of the docking box
-    docked_ligand_file : Optional[str] (Default = None)
-        the filepath of a file containing the coordinates of a docked ligand
-    use_largest : bool (Default = False)
-        whether to use the largest cluster of spheres when selecting spheres
-    buffer : float (Default = 10.)
-        the amount of buffer space to be added around the docked ligand when
-        selecting spheres and when constructing the docking box if
-        enclose_spheres is True
-    enclose_spheres : bool (Default = True)
-        whether to calculate the docking box by enclosing the selected spheres
-        or to use an input center and radii
-
-    Returns
-    -------
-    sph_grid : Optional[Tuple[str, str]]
-        A tuple of strings with the first entry being the filepath of the file
-        containing the selected spheres and the second being entry the prefix
-        of all prepared grid files. None if receptor preparation fails at any
-        point
-    """
-    rec_mol2 = prepare_mol2(receptor, path)
-    rec_pdb = prepare_pdb(receptor, path)
-    if rec_mol2 is None or rec_pdb is None:
-        return None
-
-    rec_dms = prepare_dms(rec_pdb, probe_radius, path)
-    if rec_dms is None:
-        return None
-
-    rec_sph = prepare_sph(rec_dms, steric_clash_dist, min_radius, max_radius, path)
-    if rec_sph is None:
-        return None
-
-    rec_sph = select_spheres(
-        rec_sph, sphere_mode, center, size, docked_ligand_file, buffer, path
-    )
-    rec_box = prepare_box(rec_sph, center, size, enclose_spheres, buffer, path)
-    if rec_box is None:
-        return None
-
-    grid_prefix = prepare_grid(rec_mol2, rec_box, path)
-    if grid_prefix is None:
-        return None
-
-    return rec_sph, grid_prefix
-
-
-def prepare_mol2(receptor: str, path: str = ".") -> Optional[str]:
+def prepare_mol2(receptor: str, path: str = ".") -> str:
     """Prepare a receptor mol2 file from its input file
 
     Parameter
     ---------
     receptor : str
         the filename of a file containing the receptor
-    path : str, default='.'
+    path : str, default="."
         the path under which to place the receptor
 
     Returns
     -------
-    receptor_mol2 : Optional[str]
-        the filename of the prepared mol2 file
+    str
+        the filepath of the prepared mol2 file
     """
     p_rec_mol2 = Path(path) / f"{Path(receptor).stem}_withH.mol2"
     argv = ["chimera", "--nogui", "--script", f"{PREP_REC} {receptor} {p_rec_mol2}"]
@@ -142,15 +76,16 @@ def prepare_mol2(receptor: str, path: str = ".") -> Optional[str]:
     try:
         ret.check_returncode()
     except sp.SubprocessError:
-        print(f'ERROR: failed to convert receptor: "{receptor}"')
-        if ret.stderr:
-            print(f'Message: {ret.stderr.decode("utf-8")}', file=sys.stderr)
-        return None
+        raise ReceptorPreparationError(
+            f'failed to prepare MOL2 "{receptor}".' + f'Message: {ret.stderr.decode("utf-8")}'
+            if ret.stderr
+            else ""
+        )
 
     return str(p_rec_mol2)
 
 
-def prepare_pdb(receptor: str, path: str = ".") -> Optional[str]:
+def prepare_pdb(receptor: str, path: str = ".") -> str:
     """Prepare a receptor PDB file for usage in DOCK runs
 
     Parameter
@@ -160,8 +95,8 @@ def prepare_pdb(receptor: str, path: str = ".") -> Optional[str]:
 
     Returns
     -------
-    receptor_mol2 : Optional[str]
-        the filename of the prepared pdb file
+    str
+        the filepath of the prepared pdb file
     """
     rec_pdb = str(Path(path) / f"DOCK_{Path(receptor).stem}.pdb")
     args = ["obabel", receptor, "-opdb", "-O", rec_pdb]
@@ -170,30 +105,31 @@ def prepare_pdb(receptor: str, path: str = ".") -> Optional[str]:
     try:
         ret.check_returncode()
     except sp.SubprocessError:
-        print(f'ERROR: failed to convert receptor: "{receptor}"')
-        if ret.stderr:
-            print(f'Message: {ret.stderr.decode("utf-8")}', file=sys.stderr)
-        return None
+        raise ReceptorPreparationError(
+            f'failed to prepare PDB for "{receptor}".'
+            + +(f'Message: {ret.stderr.decode("utf-8")}' if ret.stderr else "")
+        )
 
     return rec_pdb
 
 
-def prepare_dms(
-    rec_pdb: str, probe_radius: float = 1.4, path: str = "."
-) -> Optional[str]:
+def prepare_dms(rec_pdb: str, probe_radius: float = 1.4, path: str = ".") -> str:
     p_rec_dms = Path(path) / f"{Path(rec_pdb).stem}.dms"
     argv = [
-        "chimera", "--nogui", "--script", f"{WRITE_DMS} {rec_pdb} {probe_radius} {str(p_rec_dms)}",
+        "chimera",
+        "--nogui",
+        "--script",
+        f"{WRITE_DMS} {rec_pdb} {probe_radius} {str(p_rec_dms)}",
     ]
 
     ret = sp.run(argv, stdout=sp.PIPE)
     try:
         ret.check_returncode()
     except sp.SubprocessError:
-        print(f'ERROR: failed to generate surface from "{rec_pdb}"', file=sys.stderr)
-        if ret.stderr:
-            print(f'Message: {ret.stderr.decode("utf-8")}', file=sys.stderr)
-        # return None
+        raise SurfaceGenerationError(
+            f'failed to generate surface for "{rec_pdb}".'
+            + (f'Message: {ret.stderr.decode("utf-8")}' if ret.stderr else "")
+        )
 
     return str(p_rec_dms)
 
@@ -207,20 +143,31 @@ def prepare_sph(
 ) -> Optional[str]:
     sph_file = str(Path(path) / f"{Path(rec_dms).stem}.sph")
     argv = [
-        SPHGEN, "-i", rec_dms, "-o", sph_file,
-        "-s", "R", "d", "X",
-        "-l", f"{steric_clash_dist:0.1f}", "m", str(min_radius),
-        "-x", f"{max_radius:0.1f}",
+        SPHGEN,
+        "-i",
+        rec_dms,
+        "-o",
+        sph_file,
+        "-s",
+        "R",
+        "d",
+        "X",
+        "-l",
+        f"{steric_clash_dist:0.1f}",
+        "m",
+        str(min_radius),
+        "-x",
+        f"{max_radius:0.1f}",
     ]
 
     ret = sp.run(argv, stdout=sp.PIPE)
     try:
         ret.check_returncode()
     except sp.SubprocessError:
-        print(f'ERROR: failed to generate spheres for "{rec_dms}"', file=sys.stderr)
-        if ret.stderr:
-            print(f'Message: {ret.stderr.decode("utf-8")}', file=sys.stderr)
-        return None
+        raise SphereGenerationError(
+            f'failed to generate spheres for "{rec_dms}".'
+            + (f'Message: {ret.stderr.decode("utf-8")}' if ret.stderr else "")
+        )
 
     return sph_file
 
@@ -271,12 +218,12 @@ def select_spheres(
 
     with open(sph_file, "r") as fid_in, open(selected_sph, "w") as fid_out:
         if sphere_mode == sphere_mode.LARGEST:
-            clusterline = lambda line: "cluster" not in line
+            clusterline = lambda line: "cluster" not in line  # noqa: E731
 
             for _ in takewhile(clusterline, fid_in):
                 continue
             lines = [line for line in takewhile(clusterline, fid_in)]
-            fid_out.write(f"DOCK spheres largest cluster\n")
+            fid_out.write("DOCK spheres largest cluster\n")
 
         elif sphere_mode == sphere_mode.BOX:
             lines = [line for line in fid_in if inside_box(line, center, size)]
@@ -302,13 +249,7 @@ def inside_box(
     bx, by, bz = center
     ra, rb, rc = size
 
-    return all(
-        [
-            bx - ra <= x <= bx + ra,
-            by - rb <= y <= by + rb,
-            bz - rc <= z <= bz + rc,
-        ]
-    )
+    return all([bx - ra <= x <= bx + ra, by - rb <= y <= by + rb, bz - rc <= z <= bz + rc])
 
 
 def prepare_box(
@@ -319,81 +260,79 @@ def prepare_box(
     buffer: float = 10.0,
     path: str = ".",
 ) -> Optional[str]:
-    shutil.copyfile(sph_file, "tmp_spheres.sph")
+    # long file paths causes issues with showbox, so use temp files with shorter names
+    TMP_SPH_FILE = "tmp_spheres.sph"
+    TMP_BOX_FILE = "tmp_box.pdb"
+
+    shutil.copyfile(sph_file, TMP_SPH_FILE)
     box_file = str(Path(path) / f"{Path(sph_file).stem}_box.pdb")
 
     if enclose_spheres:
-        showbox_input = f"Y\n{buffer}\ntmp_spheres.sph\n1\n"
+        showbox_input = f"Y\n{buffer}\n{TMP_SPH_FILE}\n1\n"
     else:
         x, y, z = center
         a, b, c = size
         showbox_input = f"N\nU\n{x} {y} {z}\n{a} {b} {c}\n"
 
-    showbox_input += "tmp_box.pdb\n"
+    showbox_input += f"{TMP_BOX_FILE}\n"
 
-    # with open('box.in', 'w') as fid:
-    #     if enclose_spheres:
-    #         fid.write('Y\n')
-    #         fid.write(f'{buffer}\n')
-    #         fid.write(f'{sph_file}\n')
-    #         fid.write(f'1\n')
-    #     else:
-    #         fid.write('N\n')
-    #         fid.write('U\n')
-    #         fid.write(f'[{center[0]} {center[1]} {center[2]}]\n')
-    #         fid.write(f'[{size[0]} {size[1]} {size[2]}]\n')
-    #     fid.write(f'{box_file}\n')
-
-    ret = sp.run(
-        [SHOWBOX], input=showbox_input, universal_newlines=True, stdout=sp.PIPE
-    )
+    ret = sp.run([SHOWBOX], input=showbox_input, universal_newlines=True, stdout=sp.PIPE)
     try:
         ret.check_returncode()
     except sp.SubprocessError:
-        print(
-            f'ERROR: failed to generate box corresponding to "{sph_file}"',
-            file=sys.stderr,
+        raise BoxGenerationError(
+            f'failed to generate generate box corresponding to "{sph_file}".'
+            + (f'Message: {ret.stderr.decode("utf-8")}' if ret.stderr else "")
         )
-        if ret.stderr:
-            print(f'Message: {ret.stderr.decode("utf-8")}', file=sys.stderr)
-        return None
 
-    os.unlink("tmp_spheres.sph")
-    shutil.move("tmp_box.pdb", box_file)
+    os.unlink(TMP_SPH_FILE)
+    shutil.move(TMP_BOX_FILE, box_file)
     return box_file
 
 
-def prepare_grid(rec_mol2: str, box_file: str, path: str = ".") -> Optional[str]:
+def prepare_grid(
+    rec_mol2: str, box_file: str, path: str = ".", params: Optional[Mapping] = None
+) -> str:
+    # grid has has problems with long file lengths, so use temp file to shorten
+    TMP_BOX_FILE = "tmp_box.pdb"
+    shutil.copy(box_file, TMP_BOX_FILE)
+
+    DEFAULT_PARAMS = {
+        "compute_grids": "yes",
+        "grid_spacing": 0.4,
+        "output_molecule": "no",
+        "contact_score": "no",
+        "energy_score": "yes",
+        "energy_cutoff_distance": 9999,
+        "atom_model": "a",
+        "attractive_exponent": 6,
+        "repulsive_exponent": 12,
+        "distance_dielectric": "yes",
+        "dielectric_factor": 4.0,
+        "bump_filter": "yes",
+        "bump_overlap": 0.75,
+    }
+    if params is None:
+        params = DEFAULT_PARAMS
+    else:
+        params = {**params, **DEFAULT_PARAMS}
     p_grid_stem = Path(path) / f"{Path(rec_mol2).stem}_grid"
 
-    shutil.copy(box_file, "tmp_box.pdb")
     with open("grid.in", "w") as fid:
-        fid.write("compute_grids yes\n")
-        fid.write("grid_spacing 0.4\n")
-        fid.write("output_molecule no\n")
-        fid.write("contact_score no\n")
-        fid.write("energy_score yes\n")
-        fid.write("energy_cutoff_distance 9999\n")
-        fid.write("atom_model a\n")
-        fid.write("attractive_exponent 6\n")
-        fid.write("repulsive_exponent 12\n")
-        fid.write("distance_dielectric yes\n")
-        fid.write("dielectric_factor 4.0\n")
-        fid.write("bump_filter yes\n")
-        fid.write("bump_overlap 0.75\n")
-        fid.write(f"receptor_file {rec_mol2}\n")
-        fid.write("box_file tmp_box.pdb\n")
-        fid.write(f"vdw_definition_file {VDW_DEFN_FILE}\n")
-        fid.write(f"score_grid_prefix  {p_grid_stem}\n")
+        [print(f"{k} {v}", file=fid) for k, v in params.items()]
+        print(f"receptor_file {rec_mol2}", file=fid)
+        print("box_file tmp_box.pdb", file=fid)
+        print(f"vdw_definition_file {VDW_DEFN_FILE}", file=fid)
+        print(f"score_grid_prefix  {p_grid_stem}", file=fid)
 
     ret = sp.run([GRID, "-i", "grid.in", "-o", "gridinfo.out"], stdout=sp.PIPE)
     try:
         ret.check_returncode()
     except sp.SubprocessError:
-        print(f"ERROR: failed to generate grid from {rec_mol2}", file=sys.stderr)
-        if ret.stderr:
-            print(f'Message: {ret.stderr.decode("utf-8")}', file=sys.stderr)
-        return None
+        raise GridGenerationError(
+            f'failed to generate generate grid from "{rec_mol2}".'
+            + (f'Message: {ret.stderr.decode("utf-8")}' if ret.stderr else "")
+        )
 
-    os.unlink("tmp_box.pdb")
+    os.unlink(TMP_BOX_FILE)
     return str(p_grid_stem)
