@@ -1,9 +1,10 @@
 from abc import ABC
 from typing import Optional, TypeVar
 
-S = TypeVar('S')
-T = TypeVar('T')
+S = TypeVar("S")
+T = TypeVar("T")
 
-class CalculationMetadata(ABC):
+
+class SimulationMetadata(ABC):
     prepared_ligand: Optional[T] = None
-    prepared_receptor: Optional[S] = None
\ No newline at end of file
+    prepared_receptor: Optional[S] = None
