@@ -2,9 +2,10 @@ from typing import List
 
 from .hist import histogram
 
+
 def postprocess(postprocessing_options: List[str], **kwargs):
-    if 'none' in postprocessing_options:
+    if "none" in postprocessing_options:
         return
 
-    if 'hist' in postprocessing_options:
-        histogram(**kwargs)
\ No newline at end of file
+    if "hist" in postprocessing_options:
+        histogram(**kwargs)
